#
# spec file for package seafile
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           seafile
Version:        9.0.13
Release:        1.1
Summary:        Cloud storage client
License:        GPL-2.0-only
URL:            https://github.com/haiwen/seafile/
Source0:        https://github.com/haiwen/seafile/archive/v%{version}.tar.gz
BuildRequires:  argon2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  intltool
BuildRequires:  libsearpc-devel
BuildRequires:  libtool
BuildRequires:  libwebsockets-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gmodule-no-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libevent_core)
BuildRequires:  pkgconfig(libevent_extra)
BuildRequires:  pkgconfig(libevent_openssl)
BuildRequires:  pkgconfig(libevent_pthreads)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(vapigen)
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  sqlite-devel
%else
BuildRequires:  pkgconfig(sqlite3)
%endif

%description
Seafile is an open source cloud storage system with features on privacy protection and teamwork. Collections of files are
called libraries, and each library can be synced separately. A library can also be encrypted with a user chosen password.
Seafile also allows users to create groups and easily sharing files into groups.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}
Requires:       libseafile0 = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n     libseafile0
Summary:        Library files for %{name}

%description -n libseafile0
The libseafile0 package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n seafile-%{version}
sed -i -e /\(DESTDIR\)/d lib/libseafile.pc.in
sed -i -e 's@#!%{_bindir}/env python@#!%{_bindir}/python3@' app/seaf-cli
sed -i -e 's@#!%{_bindir}/python33@#!%{_bindir}/python3@' app/seaf-cli

%build
./autogen.sh
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -name '*.a' -exec rm -f {} ';'
find %{buildroot} -name 'seafile.desktop' -exec rm -f {} ';'
find %{buildroot} -type f -name "*.opt-1.pyc" -delete -print

%post -n libseafile0 -p /sbin/ldconfig
%postun -n libseafile0 -p /sbin/ldconfig

%files
%doc README.markdown
%license LICENSE.txt
%{python3_sitearch}/%{name}/
%{python3_sitearch}/seafile/
%{_bindir}/seaf-cli
%{_bindir}/seaf-daemon
%{_mandir}/man1/*.1%{?ext_man}

%files -n libseafile0
%{_libdir}/libseafile.so.0*

%files devel
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Apr 15 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.13:
  * Support lock office file on linux (#2889)
  * Add stopped by logout sync error (#2894)
  * Check and load ca path (#2885)
  * Use int as return value (#2874)
  * Check if dir is ignored and if file exists when record "index error" (#2863)
  * Don't set timeout for fs-id-list (#2862)
  * Add option to ignore symbol link (#2861)
  * Ignore case conflict error on linux (#2857)
  * Support GNUTLS (#2848)
  * Ignore checkout . and .. (#2841)
  * Hide windows incompatible path msg by default (#2847)
  * Check pwd hash and add crypt header (#2844)
* Mon Oct 21 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.9:
  * Support password hash (#2783)
  * Save block file directly (#2834)
  * Add auth header (#2821)
  * Upgrade to Qt 6.5
  * Fix GCC 14.1 build issues
  * Fix unlock file error and only record sync error (#2772)
  * Socks5 support username and password (#2768)
  * Check path is case conflict when checkout files (#2748)
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- The -devel package must require the library package (Requires:
  libseafile0 = %%{version}); otherwise we install a dangling
  symlink.
* Mon Feb 26 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.4:
  * Add a file-level error when failed to checkout file by @feiniks in #2692
  * Add option to build websockets by @feiniks in #2693
  * Add block missing sync error by @feiniks in #2694
  * Only record a file-level error,don't send notification by @feiniks in #2701
  * Upgrade to Qt 6.5.2 by @rumtid in #2695
  * Add compile linux websockets macro by @feiniks in #2703
* Mon Jul  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.3 (no changelog).
* Wed Apr 12 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 9.0.1 (no changelog).
* Tue Jan  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.10 (no changelog).
* Mon Nov  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.9:
  * Add confirmation when deleting more than 500 files.
  * Don't create commit from index and don't write duplicate name cache to index.
* Wed Jul 13 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.8 (no changelog)
* Mon May  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.7 (no changelog)
* Thu Feb 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.6 (no changelog)
- Remove seafile-fix-compilation-glib2_68.patch
* Fri Dec 10 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.5. No changelog.
* Tue Sep 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.4. No changelog.
* Sun Jun 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.0.3. No changelog.
* Wed May 26 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.0.2 (no changelog)
* Wed Apr 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Add seafile-fix-compilation-glib2_68.patch
* Mon Oct 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.0.10 (no changelog)
* Mon Aug 10 2020 Paolo Stivanin <info@paolostivanin.com>
- For some reasons (very likely a typo), seaf-cli had python33
  instead of python3 set as interpreter. An additional 'sed' was
  added to the spec file
* Fri Jul 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.0.9 (no changelog)
* Mon Jun  8 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.0.8 (no changelog)
* Fri Apr 10 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.7 (no changelog)
* Tue Mar 10 2020 Paolo Stivanin <info@paolostivanin.com>
- Remove ccnet dep as it is no longer needed
* Mon Feb 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.6
* Tue Jan 14 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.5
* Thu Nov 21 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.4
* Fri Nov 15 2019 Paolo Stivanin <info@paolostivanin.com>
- run spec-cleaner
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Fix spec file
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Fix license
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Rename package from libseafile to seafile
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.3
* Mon Aug 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.2
* Wed Jun 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.1
* Fri May 31 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to v7.0.0
* Fri Jan 18 2019 Paolo Stivanin <pstivanin@suse.com>
- Update to v6.2.11
* Thu Dec 13 2018 Paolo Stivanin <pstivanin@suse.com>
- Use correct archive for libseafile
* Thu Dec 13 2018 Paolo Stivanin <pstivanin@suse.com>
- Update to v6.2.9
* Sat Sep 15 2018 Paolo Stivanin <info@paolostivanin.com>
- Add current archive, delete old version
* Sat Sep 15 2018 Paolo Stivanin <info@paolostivanin.com>
- Update to v6.2.5
* Sat Aug  4 2018 christoph@stop.pe
- Updated to version 6.2.4
* Tue May 22 2018 christoph@stop.pe
- Removed obsolete patch
* Tue May 22 2018 christoph@stop.pe
- Updated to version 6.1.8
* Wed Mar 28 2018 christoph@stop.pe
- Fixed build errors on CentOS 7
* Sun Dec 31 2017 christoph@stop.pe
- Updated to version 6.1.4
* Thu Dec  7 2017 christoph@stop.pe
- Fixed groups in spec file
* Thu Dec  7 2017 christoph@stop.pe
- Updated to version 6.1.3
* Sat Feb 25 2017 christoph@stop.pe
- Updated to version 6.0.4
* Sun Sep 25 2016 christoph@stop.pe
- Initial packaging
